import React, { useEffect, useState } from 'react'
import axios from 'axios'
import { Link, useParams } from 'react-router-dom'
import { API_BASE_URL } from '@/config'
import TagSearch from './TagSearch'
import SidebarComponent from './layout/SidebarComponent'

import type { Post, Tag } from '@/types'

type TagByCategory = { [key: string]: Tag[] }

type Props = { posts: Post[] }


const tagNameMap: { [key: string]: string } = {
    general:    '一般',
    deerjikist: 'ニジラー',
    nico:       'ニコニコタグ' }


export default ({ posts }: Props) => {
  const [tags, setTags] = useState<TagByCategory> ({ })
  const [tagsCounts, setTagsCounts] = useState<{ [key: number]: number }> ({ })

  useEffect (() => {
    const tagsTmp: TagByCategory = { }
    const tagsCountsTmp: { [key: number]: number } = { }
    for (const post of posts)
      {
        for (const tag of post.tags)
          {
            if (!(tag.category in tagsTmp))
              tagsTmp[tag.category] = []
            if (!(tagsTmp[tag.category].map (t => t.id).includes (tag.id)))
              tagsTmp[tag.category].push (tag)
            if (!(tag.id in tagsCountsTmp))
              tagsCountsTmp[tag.id] = 0
            ++tagsCountsTmp[tag.id]
          }
      }
    for (const cat of Object.keys (tagsTmp))
      tagsTmp[cat].sort ((tagA, tagB) => tagA.name < tagB.name ? -1 : 1)
    setTags (tagsTmp)
    setTagsCounts (tagsCountsTmp)
  }, [posts])

  return (
      <SidebarComponent>
        <TagSearch />
        {['general', 'deerjikist', 'nico'].map (cat => cat in tags && <>
            <h2>{tagNameMap[cat]}</h2>
            <ul>
              {tags[cat].map (tag => (
                  <li key={tag.id} className="mb-2">
                    <Link to={`/posts?${ (new URLSearchParams ({ tags: tag.name })).toString () }`}
                          className="text-blue-600 hover:underline">
                      {tag.name}
                    </Link>
                    <span className="ml-1">{tagsCounts[tag.id]}</span>
                  </li>))}
            </ul>
            </>)}
      </SidebarComponent>)
}
